==> haskell-regex-base-0.93.2-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-base
version: 0.93.2
id: regex-base-0.93.2-rcKBNTI69reeBx0eaPBC
key: regex-base-0.93.2-rcKBNTI69reeBx0eaPBC
license: BSD3
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
stability: Seems to work, passes a few tests
homepage: http://sourceforge.net/projects/lazy-regex
package-url: http://darcs.haskell.org/packages/regex-unstable/regex-base/
synopsis: Replaces/Enhances Text.Regex
description:
    Interface API for regex-posix,pcre,parsec,tdfa,dfa
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike
abi: 3a05b32d0b549c5eb87dc4762955a2ed
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-base-0.93.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-base-0.93.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/regex-base-0.93.2
hs-libraries: HSregex-base-0.93.2-rcKBNTI69reeBx0eaPBC
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
haddock-interfaces: /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html: /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-base-0.93.2-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-base
version: 0.93.2
id: regex-base-0.93.2-2WymZ6oErYqGB0H6LBWVXT
key: regex-base-0.93.2-2WymZ6oErYqGB0H6LBWVXT
license: BSD3
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
stability: Seems to work, passes a few tests
homepage: http://sourceforge.net/projects/lazy-regex
package-url: http://darcs.haskell.org/packages/regex-unstable/regex-base/
synopsis: Replaces/Enhances Text.Regex
description:
    Interface API for regex-posix,pcre,parsec,tdfa,dfa
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike
abi: 00b0a18913cb065ba60dd774df7963ef
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-base-0.93.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-base-0.93.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/regex-base-0.93.2
hs-libraries: HSregex-base-0.93.2-2WymZ6oErYqGB0H6LBWVXT
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
haddock-interfaces: /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html: /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
